@@ -397,7 +397,7 @@ dconf_engine_read_internal (DConfEngine  *engine,
    * ensure that values in the user database are always ignored when
    * locks are present.
    */
-  for (i = engine->n_dbs - 1; lowest < i; i--)
+  for (i = MAX (engine->n_dbs - 1, lowest); lowest < i; i--)
     if (engine->lock_tables[i] != NULL &&
         gvdb_table_has_value (engine->lock_tables[i], key))
       break;
@@ -637,14 +637,10 @@ dconf_engine_write_many (DConfEngine          *engine,
 gchar **
 dconf_engine_list (DConfEngine    *engine,
                    const gchar    *dir,
-                   DConfResetList *resets,
                    gint           *length)
 {
   gchar **list;
 
-  /* not yet supported */
-  g_assert (resets == NULL);
-
   g_mutex_lock (&engine->lock);
 
   dconf_engine_refresh (engine);
